<?php
/**
 * Plugin Name:       WoPo Paint - Web Based drawing tool
 * Plugin URI:        https://wopoweb.com/product/wopo-paint/
 * Description:       A nice web-based MS Paint remake and more...
 * Version:           1.1.1
 * Requires at least: 5.2
 * Requires PHP:      7.1
 * Author:            WoPo Web
 * Author URI:        https://wopoweb.com
 * License:           GPL v2 or later
 * License URI:       https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain:       wopo-paint
 * Domain Path:       /languages
 */

function wopop_settings_init()
{
    // register a new setting for "reading" page
    register_setting('general', 'wopop_imgur_api');
 
    // register a new section in the "reading" page
    add_settings_section(
        'wopop_settings_section',
        'WoPo Paint Settings Section',
        'wopop_settings_section_cb',
        'general'
    );
 
    // register a new field in the "wporg_settings_section" section, inside the "reading" page
    add_settings_field(
        'wopoccw_settings_field',
        'Imgur API key',
        'wopop_settings_field_cb',
        'general',
        'wopop_settings_section'
    );
}
 
/**
 * register wporg_settings_init to the admin_init action hook
 */
add_action('admin_init', 'wopop_settings_init');
 
/**
 * callback functions
 */
 
// section content cb
function wopop_settings_section_cb()
{
    $designer_url = wopop_get_editor_url();
    echo '<p>WoPo Paint Designer URL: <a target="_blank" href="'.$designer_url.'">'.$designer_url.'</a></p>';
}
 
// field content cb
function wopop_settings_field_cb()
{
    // get the value of the setting we've registered with register_setting()
    $api_key = get_option('wopop_imgur_api');
    // output the field
    ?>
    <a id="wopop_imgur_api_field"></a>
    <input type="password" name="wopop_imgur_api" value="<?php echo isset( $api_key ) ? esc_attr( $api_key ) : ''; ?>">    
    <?php
}

function wopop_get_editor_url(){
    return plugins_url('editor/index.html',__FILE__);
}

add_action('wp_enqueue_scripts', 'wopop_enqueue_scripts');

function wopop_enqueue_scripts(){
    global $post;
    $is_shortcode = intval(has_shortcode( $post->post_content, 'wopo-paint'));
    if ((function_exists('wopopp_add_drawing_button') && is_singular()) || $is_shortcode){
        wp_enqueue_style('XP',plugins_url( '/assets/css/XP.css', __FILE__ ));
        wp_enqueue_style('wopo-paint',plugins_url( '/assets/css/main.css', __FILE__ ));
        wp_enqueue_script('wopo-paint', plugins_url( '/assets/js/main.js', __FILE__ ),array('jquery'));
        $title_nonce = wp_create_nonce( 'wopo_paint' );
        wp_localize_script( 'wopo-paint', 'wopoPaint', array(
            'ajax_url' => admin_url( 'admin-ajax.php' ),
            'painter_url' => wopop_get_editor_url(),
            'nonce'    => $title_nonce, 
            'post_id' => get_the_ID(),
            'is_shortcode' => $is_shortcode,
        ) ); 
        do_action('wopo_paint_enqueue_scripts');
    }
}

add_shortcode('wopo-paint', 'wopo_paint_shortcode');
function wopo_paint_shortcode( $atts = [], $content = null) {
    ob_start();?>
    <div id="wopo_painter_window" class="window">
        <div class="title-bar">
            <div class="title-bar-text"><?= __('WoPo Paint - Drawing online for Wordpress','wopo-paint') ?></div>
            <div class="title-bar-controls">
            <button class="btn-minimize" aria-label="Minimize"></button>
            <button class="btn-maximize" aria-label="Maximize"></button>
            <button class="btn-close" aria-label="Close"></button>
            </div>
        </div>
        <div class="window-body">
            <iframe id="wopo_painter"></iframe>
        </div>
    </div>
    <?php
    $content = ob_get_clean();
    return $content;
}